@@ -14,7 +14,23 @@ Information sourced from u-blox Interface Specifications © 2013-2021, u-blox AG
 """
 # pylint: disable=too-many-lines
 
-from pyubx2.ubxtypes_core import E1, E2, I1, I2, I4, R4, R8, U1, U2, U4, U8, X1, X8, L
+from pyubx2.ubxtypes_core import (
+    E1,
+    E2,
+    I1,
+    I2,
+    I4,
+    R4,
+    R8,
+    U1,
+    U2,
+    U4,
+    U8,
+    X1,
+    X2,
+    X8,
+    L,
+)
 
 # memory layer designators for CFG_VALSET & CFG_VALDEL
 SET_LAYER_RAM = 1
@@ -943,6 +959,12 @@ UBX_CONFIG_DATABASE = {
     "CFG_NAVMASK_EL_MASK_300_320": (0x50180010, X8),
     "CFG_NAVMASK_EL_MASK_320_340": (0x50180011, X8),
     "CFG_NAVMASK_EL_MASK_340_360": (0x50180012, X8),
+    "CFG_NAVMASK_SV_MASK_BDS": (0x50180016, X8),
+    "CFG_NAVMASK_SV_MASK_GAL": (0x50180014, X8),
+    "CFG_NAVMASK_SV_MASK_GLO": (0x50180015, X8),
+    "CFG_NAVMASK_SV_MASK_GPS": (0x50180013, X8),
+    "CFG_NAVMASK_SV_MASK_NAVIC": (0x50180018, X8),
+    "CFG_NAVMASK_SV_MASK_QZSS": (0x50180017, X8),
     "CFG_NAVSPG_ACKAIDING": (0x10110025, L),
     "CFG_NAVSPG_CONSTR_ALT": (0x401100C1, I4),
     "CFG_NAVSPG_CONSTR_ALTVAR": (0x401100C2, U4),
@@ -1057,14 +1079,17 @@ UBX_CONFIG_DATABASE = {
     "CFG_RTCM_DF003_IN_FILTER": (0x20090009, E1),
     "CFG_RTCM_DF003_IN": (0x30090008, U2),
     "CFG_RTCM_DF003_OUT": (0x30090001, U2),
+    "CFG_SBAS_ACCEPT_NOT_IN_PRNMASK": (0x30360008, X2),
     "CFG_SBAS_PRNSCANMASK": (0x50360006, X8),
     "CFG_SBAS_USE_DIFFCORR": (0x10360004, L),
     "CFG_SBAS_USE_INTEGRITY": (0x10360005, L),
+    "CFG_SBAS_USE_IONOONLY": (0x10360007, L),
     "CFG_SBAS_USE_RANGING": (0x10360003, L),
     "CFG_SBAS_USE_TESTMODE": (0x10360002, L),
     "CFG_SEC_CFG_LOCK_UNLOCKGRP1": (0x30F6000A, U2),
     "CFG_SEC_CFG_LOCK_UNLOCKGRP2": (0x30F6000B, U2),
     "CFG_SEC_CFG_LOCK": (0x10F60009, L),
+    "CFG_SEC_JAMDET_SENSITIVITY_HI": (0x10F60051, L),
     "CFG_SFCORE_HNR_RATE": (0x2008001A, U1),
     "CFG_SFCORE_USE_SF": (0x10080001, L),
     "CFG_SFIMU_ACCEL_ACCURACY": (0x30060018, U2),
