@@ -9,7 +9,6 @@ Information sourced from public domain u-blox Interface Specifications © 2013-2
 """
 
 UBX_HDR = b"\xb5\x62"
-NMEA_HDR = [b"\x24\x47", b"\x24\x50"]
 GET = 0
 SET = 1
 POLL = 2
@@ -209,6 +208,7 @@ UBX_MSGIDS = {
     b"\x10\x15": "ESF-INS",
     b"\x10\x02": "ESF-MEAS",
     b"\x10\x03": "ESF-RAW",
+    b"\x10\x13": "ESF-RESETALG",  # referenced but not defined in specs
     b"\x10\x10": "ESF-STATUS",
     # ***************************************************************
     # High Rate Navigation messages
