@@ -1192,7 +1192,7 @@ UBX_PAYLOADS_GET = {
                 "angleError": U1,
             },
         ),
-        "reserved1": U1,
+        "reserved0": U1,
         "yaw": [U4, SCAL2],
         "pitch": [I2, SCAL2],
         "roll": [I2, SCAL2],
@@ -1221,14 +1221,14 @@ UBX_PAYLOADS_GET = {
             {
                 "version": U8,
                 "xAngRateValid": U1,
-                "AngRateValid": U1,
+                "yAngRateValid": U1,
                 "zAngRateValid": U1,
                 "xAccelValid": U1,
                 "yAccelValid": U1,
                 "zAccelValid": U1,
             },
         ),
-        "reserved1": U4,
+        "reserved0": U4,
         "iTOW": U4,
         "xAngRate": [I4, SCAL3],
         "yAngRate": [I4, SCAL3],
@@ -1277,7 +1277,21 @@ UBX_PAYLOADS_GET = {
     "ESF-STATUS": {
         "iTOW": U4,
         "version": U1,
-        "reserved0": U7,
+        "initStatus1": (
+            X1,
+            {
+                "wtInitStatus": U2,
+                "mntAlgStatus": U3,
+                "insInitStatus": U3,
+            },
+        ),
+        "initStatus2": (
+            X1,
+            {
+                "imuInitStatus": U2,
+            },
+        ),
+        "reserved0": U5,
         "fusionMode": U1,
         "reserved1": U2,
         "numSens": U1,
@@ -1809,7 +1823,7 @@ UBX_PAYLOADS_GET = {
                 "flags": (
                     X1,
                     {
-                        "jammingState": U1,
+                        "jammingState": U2,
                     },
                 ),
                 "antStatus": U1,
@@ -1818,7 +1832,7 @@ UBX_PAYLOADS_GET = {
                 "reserved1": U4,
                 "noisePerMS": U2,
                 "agcCnt": U2,
-                "jamInd": U1,
+                "jamInd": U1,  # aka cwSuppression
                 "ofsI": I1,
                 "magI": U1,
                 "ofsQ": I1,
@@ -3565,6 +3579,7 @@ UBX_PAYLOADS_GET = {
                 "utc": U1,
                 "raim": U2,
                 "qErrInvalid": U1,
+                "TpNotLocked": U1,  # deprecated bit flag
             },
         ),
         "refinfo": (
